==> monaco-vscode-user-data-profile-service-override-7.0.9.tgz: package/vscode/src/vs/workbench/services/userDataSync/common/userDataSyncUtil.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { IKeybindingService } from 'vscode/vscode/vs/platform/keybinding/common/keybinding.service';
import { getDefaultIgnoredSettings } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';
import 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import 'vscode/vscode/vs/platform/instantiation/common/extensions';
import { ITextModelService } from 'vscode/vscode/vs/editor/common/services/resolverService';
import { ITextResourcePropertiesService, ITextResourceConfigurationService } from 'vscode/vscode/vs/editor/common/services/textResourceConfiguration';

let UserDataSyncUtilService = class UserDataSyncUtilService {
    constructor(keybindingsService, textModelService, textResourcePropertiesService, textResourceConfigurationService) {
        this.keybindingsService = keybindingsService;
        this.textModelService = textModelService;
        this.textResourcePropertiesService = textResourcePropertiesService;
        this.textResourceConfigurationService = textResourceConfigurationService;
    }
    async resolveDefaultIgnoredSettings() {
        return getDefaultIgnoredSettings();
    }
    async resolveUserBindings(userBindings) {
        const keys = {};
        for (const userbinding of userBindings) {
            keys[userbinding] = ( this.keybindingsService.resolveUserBinding(userbinding).map(part => part.getUserSettingsLabel())).join(' ');
        }
        return keys;
    }
    async resolveFormattingOptions(resource) {
        try {
            const modelReference = await this.textModelService.createModelReference(resource);
            const { insertSpaces, tabSize } = modelReference.object.textEditorModel.getOptions();
            const eol = modelReference.object.textEditorModel.getEOL();
            modelReference.dispose();
            return { eol, insertSpaces, tabSize };
        }
        catch (e) {
        }
        return {
            eol: this.textResourcePropertiesService.getEOL(resource),
            insertSpaces: !!this.textResourceConfigurationService.getValue(resource, 'editor.insertSpaces'),
            tabSize: this.textResourceConfigurationService.getValue(resource, 'editor.tabSize')
        };
    }
};
UserDataSyncUtilService = ( __decorate([
    ( __param(0, IKeybindingService)),
    ( __param(1, ITextModelService)),
    ( __param(2, ITextResourcePropertiesService)),
    ( __param(3, ITextResourceConfigurationService))
], UserDataSyncUtilService));

export { UserDataSyncUtilService };

==> monaco-vscode-user-data-profile-service-override-8.0.4.tgz: package/vscode/src/vs/workbench/services/userDataSync/common/userDataSyncUtil.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { IKeybindingService } from 'vscode/vscode/vs/platform/keybinding/common/keybinding.service';
import { getDefaultIgnoredSettings } from 'vscode/vscode/vs/platform/userDataSync/common/userDataSync';
import 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import 'vscode/vscode/vs/platform/instantiation/common/extensions';
import { ITextModelService } from 'vscode/vscode/vs/editor/common/services/resolverService';
import { ITextResourcePropertiesService, ITextResourceConfigurationService } from 'vscode/vscode/vs/editor/common/services/textResourceConfiguration';

let UserDataSyncUtilService = class UserDataSyncUtilService {
    constructor(keybindingsService, textModelService, textResourcePropertiesService, textResourceConfigurationService) {
        this.keybindingsService = keybindingsService;
        this.textModelService = textModelService;
        this.textResourcePropertiesService = textResourcePropertiesService;
        this.textResourceConfigurationService = textResourceConfigurationService;
    }
    async resolveDefaultCoreIgnoredSettings() {
        return getDefaultIgnoredSettings(true);
    }
    async resolveUserBindings(userBindings) {
        const keys = {};
        for (const userbinding of userBindings) {
            keys[userbinding] = ( this.keybindingsService.resolveUserBinding(userbinding).map(part => part.getUserSettingsLabel())).join(' ');
        }
        return keys;
    }
    async resolveFormattingOptions(resource) {
        try {
            const modelReference = await this.textModelService.createModelReference(resource);
            const { insertSpaces, tabSize } = modelReference.object.textEditorModel.getOptions();
            const eol = modelReference.object.textEditorModel.getEOL();
            modelReference.dispose();
            return { eol, insertSpaces, tabSize };
        }
        catch (e) {
        }
        return {
            eol: this.textResourcePropertiesService.getEOL(resource),
            insertSpaces: !!this.textResourceConfigurationService.getValue(resource, 'editor.insertSpaces'),
            tabSize: this.textResourceConfigurationService.getValue(resource, 'editor.tabSize')
        };
    }
};
UserDataSyncUtilService = ( __decorate([
    ( __param(0, IKeybindingService)),
    ( __param(1, ITextModelService)),
    ( __param(2, ITextResourcePropertiesService)),
    ( __param(3, ITextResourceConfigurationService))
], UserDataSyncUtilService));

export { UserDataSyncUtilService };
